# -*- coding: utf-8 -*-
"""Specifies the version of the FeatureWiz package."""

__title__ = "featurewiz"
__author__ = "Ram Seshadri"
__description__ = "Fast Feature Engineering and Feature Selection for any data set, any size"
__url__ = "https://github.com/Auto_ViML/featurewiz.git"
__version__ = "0.0.21"
__license__ = "Apache License 2.0"
__copyright__ = "2020 Google"
